@@ -1,7 +1,7 @@
 ;;; wget.el --- Interface program of wget on Emacs
 
-;; Copyright (C) 2001, 2002 Masayuki Ataka <ataka@milk.freemail.ne.jp>
-;;	$Id: wget.el,v 1.51 2002/11/29 07:17:42 m1378502 Exp $	
+;; Copyright (C) 2001, 2002, 2003 Masayuki Ataka <ataka@milk.freemail.ne.jp>
+;;	$Id: wget.el,v 1.53 2003/05/12 19:21:37 m1378502 Exp $	
 
 ;; Author: Masayuki Ataka <ataka@milk.freemail.ne.jp>
 ;; Keywords: hypermedia, WWW
@@ -319,7 +319,7 @@ Otherwise, Ask where to download.
 When download dir is not a directory or not writable, error"
   (let ((download (expand-file-name 
 		   (if arg
-		       (read-directory-name "Download directory: " wget-download-directory)
+		       (wget-read-directory-name "Download directory: " wget-download-directory)
 		     wget-download-directory))))
     (if (file-exists-p download)
 	(if (file-directory-p download)
@@ -412,7 +412,7 @@ process."
 	 (buf  wget-process-buffer)
 	 (lang (concat "LANG=" (getenv "LANG")))
 	 (process-environment (cons "LANG=C"
-				    (delete lang process-environment)))
+				    (delete lang (copy-sequence process-environment))))
 	 (proc (apply 'start-process "wget" buf wget-command args))
 	 (win  (selected-window)))
     ;; Initialize property.
